==> gadmin-openvpn-client_0.1.1.orig.tar.gz: gadmin-openvpn-client-0.1.1/src/widgets.c <==
/* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn client.
 * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
*/



#include <gtk/gtk.h>

/* Make sure we have enough of these or itll borrow from the next widget-type and fail */
#define NUM_SERVERTAB_ENTRIES 25
#define NUM_SERVERTAB_SPINBUTTONS 13
#define NUM_SERVERTAB_COMBOS 16


#define NUM_USERTAB_ENTRIES 7
#define NUM_USERTAB_SPINBUTTONS 1
#define NUM_USERTAB_CHECKBUTTONS 3
#define NUM_USERTAB_COMBOS 1


typedef struct w
{
  GtkWidget *main_window;
  GtkWidget *main_vbox;

  GtkWidget *main_notebook;
  GtkWidget *notebook_vbox1;
  GtkWidget *notebook_vbox2;
  GtkWidget *notebook_vbox3;
  GtkWidget *notebook_vbox4;
  GtkWidget *notebook_vbox5;
  GtkWidget *notebook_vbox6;
  GtkWidget *notebook_vbox7;
  GtkWidget *notebook_vbox8;

  GtkWidget *status_label;
  GtkWidget *version_label;

  /* The client tab's widgets */
  GtkWidget *connection_treeview;
  GtkListStore *connection_store;
  GtkWidget *connection_settings_vbox;
  GtkWidget *connection_settings_scrolled_window;

  GtkWidget *client_set_entry[NUM_SERVERTAB_ENTRIES];
  GtkWidget *client_set_spinbutton[NUM_SERVERTAB_SPINBUTTONS];
  GtkWidget *client_set_combo[NUM_SERVERTAB_COMBOS];
  GtkWidget *srv_set_table;

  /* Import widgets */
  GtkWidget *import_window;
  GtkWidget *import_treeview;
  GtkListStore *import_store;
  GtkWidget *import_file_entry;

  /* The access tab's widgets */
  GtkWidget *access_treeview;
  GtkListStore *access_store;
  GtkListStore *access_combo_list[2];
  GtkCellRenderer *access_cell[3];


  /* The user tab's widgets */
  GtkWidget *user_treeview;
  GtkListStore *user_store;
  GtkWidget *user_settings_vbox;
  GtkWidget *user_settings_scrolled_window;
  GtkWidget *user_set_entry[NUM_USERTAB_ENTRIES];
  GtkWidget *user_set_spinbutton[NUM_USERTAB_SPINBUTTONS];
  GtkWidget *user_set_checkbutton[NUM_USERTAB_CHECKBUTTONS];
  GtkWidget *user_set_combo[NUM_USERTAB_COMBOS];
  GtkWidget *gen_cert_progressbar;
  GtkWidget *usr_set_table;

  /* The user settings widgets */
  GtkWidget *useradd_username_entry;
  GtkWidget *useradd_password_entry;
  GtkWidget *useradd_homedir_entry;
  GtkWidget *useradd_usercomment_entry;
  GtkWidget *useradd_shell_combo;

  /* The delete system user question window */
  GtkWidget *del_system_user_question_window;

  /* The add default configuration question window */
  GtkWidget *default_conf_question_window;

  /* The email client tabs widgets */
  GtkWidget *client_set_table;
  GtkWidget *client_vbox;
  GtkWidget *client_scrolled_window;
  GtkWidget *client_textview;
  GtkWidget *client_from_entry;
  GtkWidget *client_to_entry;
  GtkWidget *client_subject_entry;
  GtkWidget *client_message_entry;

  /* The disc tabs widgets */
  GtkWidget *disc_treeview;
  GtkListStore *disc_store;

  /* The file treeview What to do with this ? */
  GtkWidget *file_treeview;
  GtkListStore *file_store;

  /* The connection tabs widgets */
  GtkWidget *conn_treeview;
  GtkListStore *conn_store;

  /* The log tabs widgets */
  GtkWidget *log_treeview;
  GtkListStore *log_store;

  /* The conf tabs textview */
  GtkWidget *conf_textview;

}wid;

==> gadmin-openvpn-client_0.1.9.orig.tar.gz: gadmin-openvpn-client-0.1.9/src/widgets.c <==
/* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn client.
 * Copyright (C) 2008 - 2012 Magnus Loef <magnus-swe@telia.com> 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
*/



#include <gtk/gtk.h>

/* Make sure we have enough of these or it will
   borrow from the next widget-type and fail */
#define NUM_ENTRIES 25
#define NUM_SPINBUTTONS 13
#define NUM_COMBOS 16


typedef struct w
{
  GtkWidget *main_window;
  GtkWidget *main_vbox;

  GtkWidget *main_notebook;
  GtkWidget *notebook_vbox1;
  GtkWidget *notebook_vbox2;
  GtkWidget *notebook_vbox3;

  GtkWidget *status_label;
  GtkWidget *version_label;

  /* The client tab's widgets */
  GtkWidget *connection_treeview;
  GtkListStore *connection_store;
  GtkWidget *connection_settings_vbox;
  GtkWidget *connection_settings_scrolled_window;

  /* The address treeview */
  GtkWidget *address_treeview;
  GtkListStore *address_store;

  GtkWidget *client_set_entry[NUM_ENTRIES];
  GtkWidget *client_set_spinbutton[NUM_SPINBUTTONS];
  GtkWidget *client_set_combo[NUM_COMBOS];

  GtkWidget *settings_table;

  /* Import widgets */
  GtkWidget *import_window;
  GtkWidget *import_treeview;
  GtkListStore *import_store;
  GtkWidget *import_package_file_entry;
  GtkWidget *import_config_file_entry;

  /* The log tabs widgets */
  GtkWidget *log_treeview;
  GtkListStore *log_store;

  /* The conf tabs textview */
  GtkWidget *conf_textview;

}wid;
